==> sdk-3.2.0-sources.jar: com/kontakt/sdk/android/ble/service/ScanCompatL.java <==
package com.kontakt.sdk.android.ble.service;

import android.annotation.TargetApi;
import android.bluetooth.BluetoothAdapter;
import android.bluetooth.le.BluetoothLeScanner;
import android.bluetooth.le.ScanCallback;
import android.bluetooth.le.ScanFilter;
import android.bluetooth.le.ScanSettings;
import android.os.Build;
import com.kontakt.sdk.android.ble.configuration.ForceScanConfiguration;
import com.kontakt.sdk.android.ble.configuration.scan.ScanContext;
import com.kontakt.sdk.android.common.log.Logger;
import com.kontakt.sdk.android.common.util.Closeables;
import java.util.ArrayList;
import java.util.List;

@TargetApi(Build.VERSION_CODES.LOLLIPOP)
final class ScanCompatL extends ScanCompat {

  private static final List<ScanFilter> EMPTY_SCAN_FILTERS = new ArrayList<>();

  public ScanConfiguration createScanConfiguration(ScanContext scanContext) {
    final BleScanCallback scanCallback = Callbacks.newCallback(scanContext);

    final ScanSettings scanSettings = new ScanSettings.Builder().setScanMode(scanContext.getScanMode().getCode()).build();
    final BleScanCallback callbackL = CallbacksL.newCallback(scanCallback);

    return new AbstractScanConfigurationL(scanContext, callbackL) {
      @Override
      public ScanSettings getScanSettings() {
        return scanSettings;
      }
    };
  }

  public ScanController createScanController(ScanConfiguration configuration, ForceScanScheduler forceScanScheduler) {
    return new ScanController.Builder().setScanPeriod(configuration.getScanContext().getScanPeriod())
        .setScanActiveRunner(RunnersL.newRunner(Runners.RunnerType.MONITOR_ACTIVE_RUNNER, configuration))
        .setScanPassiveRunner(RunnersL.newRunner(Runners.RunnerType.MONITOR_PASSIVE_RUNNER, configuration))
        .setForceScanScheduler(forceScanScheduler)
        .build();
  }

  public ForceScanScheduler createForceScanScheduler(final ScanConfiguration configuration) {
    final ScanContext scanContext = configuration.getScanContext();
    if (scanContext.getForceScanConfiguration() == ForceScanConfiguration.DISABLED) {
      return ForceScanScheduler.DISABLED;
    }
    return new ForceScanScheduler(RunnersL.newRunner(Runners.RunnerType.FORCE_SCAN_RUNNER, configuration));
  }

  @SuppressWarnings("MissingPermission")
  public void onScanStart(final ScanConfiguration configuration) {
    final ScanConfigurationL scanConfiguration = (ScanConfigurationL) configuration;
    final ScanSettings scanSettings = scanConfiguration.getScanSettings();
    final ScanCallback scanCallback = (ScanCallback) scanConfiguration.getScanCallback();
    final BluetoothLeScanner scanner = getScanner();

    if (scanner != null) {
      scanner.startScan(EMPTY_SCAN_FILTERS, scanSettings, scanCallback);
    } else {
      Logger.e("onRangingStart(): BluetoothLeScanner is null.");
    }
  }

  @SuppressWarnings("MissingPermission")
  public void onScanStop(BleScanCallback callback) {
    if (callback != null) {
      final ScanCallback scanCallback = (ScanCallback) callback;
      final BluetoothLeScanner scanner = getScanner();
      if (scanner != null) {
        scanner.flushPendingScanResults(scanCallback);
        scanner.stopScan(scanCallback);
      }
      Closeables.closeQuietly(callback);
    }
  }

  @TargetApi(Build.VERSION_CODES.LOLLIPOP)
  private static BluetoothLeScanner getScanner() {
    BluetoothAdapter adapter = BluetoothAdapter.getDefaultAdapter();
    if (adapter != null) {
      return adapter.getBluetoothLeScanner();
    }
    return null;
  }
}

==> sdk-3.3.0-sources.jar: com/kontakt/sdk/android/ble/service/ScanCompatL.java <==
package com.kontakt.sdk.android.ble.service;

import android.annotation.TargetApi;
import android.bluetooth.BluetoothAdapter;
import android.bluetooth.le.BluetoothLeScanner;
import android.bluetooth.le.ScanCallback;
import android.bluetooth.le.ScanFilter;
import android.bluetooth.le.ScanSettings;
import android.os.Build;
import com.kontakt.sdk.android.ble.cache.FutureShufflesCache;
import com.kontakt.sdk.android.ble.configuration.ForceScanConfiguration;
import com.kontakt.sdk.android.ble.configuration.ScanContext;
import com.kontakt.sdk.android.ble.monitoring.IEventCollector;
import com.kontakt.sdk.android.common.log.Logger;
import com.kontakt.sdk.android.common.util.Closeables;
import java.util.ArrayList;
import java.util.List;

@TargetApi(Build.VERSION_CODES.LOLLIPOP)
final class ScanCompatL extends ScanCompat {

  private static final List<ScanFilter> EMPTY_SCAN_FILTERS = new ArrayList<>();

  public ScanConfiguration createScanConfiguration(ScanContext scanContext, FutureShufflesCache cache, IEventCollector eventCollector) {
    final BleScanCallback scanCallback = Callbacks.newCallback(scanContext, cache, eventCollector);
    final ScanSettings scanSettings = new ScanSettings.Builder().setScanMode(scanContext.getScanMode().getCode()).build();
    final BleScanCallback callbackL = CallbacksL.newCallback(scanCallback);

    return new AbstractScanConfigurationL(scanContext, callbackL) {
      @Override
      public ScanSettings getScanSettings() {
        return scanSettings;
      }
    };
  }

  public ScanController createScanController(ScanConfiguration configuration, ForceScanScheduler forceScanScheduler) {
    return new ScanController.Builder().setScanPeriod(configuration.getScanContext().getScanPeriod())
        .setScanActiveRunner(RunnersL.newRunner(Runners.RunnerType.MONITOR_ACTIVE_RUNNER, configuration))
        .setScanPassiveRunner(RunnersL.newRunner(Runners.RunnerType.MONITOR_PASSIVE_RUNNER, configuration))
        .setForceScanScheduler(forceScanScheduler)
        .build();
  }

  public ForceScanScheduler createForceScanScheduler(final ScanConfiguration configuration) {
    final ScanContext scanContext = configuration.getScanContext();
    if (scanContext.getForceScanConfiguration() == ForceScanConfiguration.DISABLED) {
      return ForceScanScheduler.DISABLED;
    }
    return new ForceScanScheduler(RunnersL.newRunner(Runners.RunnerType.FORCE_SCAN_RUNNER, configuration));
  }

  @SuppressWarnings("MissingPermission")
  public void onScanStart(final ScanConfiguration configuration) {
    final ScanConfigurationL scanConfiguration = (ScanConfigurationL) configuration;
    final ScanSettings scanSettings = scanConfiguration.getScanSettings();
    final ScanCallback scanCallback = (ScanCallback) scanConfiguration.getScanCallback();
    final BluetoothLeScanner scanner = getScanner();

    if (scanner != null) {
      scanner.startScan(EMPTY_SCAN_FILTERS, scanSettings, scanCallback);
    } else {
      Logger.e("onRangingStart(): BluetoothLeScanner is null.");
    }
  }

  @SuppressWarnings("MissingPermission")
  public void onScanStop(BleScanCallback callback) {
    if (callback != null) {
      final ScanCallback scanCallback = (ScanCallback) callback;
      final BluetoothLeScanner scanner = getScanner();
      if (scanner != null) {
        scanner.flushPendingScanResults(scanCallback);
        scanner.stopScan(scanCallback);
      }
      Closeables.closeQuietly(callback);
    }
  }

  @TargetApi(Build.VERSION_CODES.LOLLIPOP)
  private static BluetoothLeScanner getScanner() {
    BluetoothAdapter adapter = BluetoothAdapter.getDefaultAdapter();
    if (adapter != null) {
      return adapter.getBluetoothLeScanner();
    }
    return null;
  }
}
